@@ -52,7 +52,7 @@ def getmsg(f, extra_ns=None, must_pass=False):
     ns = {}
     if extra_ns is not None:
         ns.update(extra_ns)
-    six.exec_(code, ns)
+    exec(code, ns)
     func = ns[f.__name__]
     try:
         func()
@@ -127,7 +127,7 @@ class TestAssertionRewrite(object):
         result = testdir.runpytest_subprocess()
         assert "warnings" not in "".join(result.outlines)
 
-    def test_name(self):
+    def test_name(self, request):
         def f():
             assert False
 
@@ -147,17 +147,41 @@ class TestAssertionRewrite(object):
         def f():
             assert sys == 42
 
-        assert getmsg(f, {"sys": sys}) == "assert sys == 42"
+        verbose = request.config.getoption("verbose")
+        msg = getmsg(f, {"sys": sys})
+        if verbose > 0:
+            assert msg == (
+                "assert <module 'sys' (built-in)> == 42\n"
+                "  -<module 'sys' (built-in)>\n"
+                "  +42"
+            )
+        else:
+            assert msg == "assert sys == 42"
 
         def f():
-            assert cls == 42  # noqa
+            assert cls == 42  # noqa: F821
 
         class X(object):
             pass
 
-        assert getmsg(f, {"cls": X}) == "assert cls == 42"
+        msg = getmsg(f, {"cls": X}).splitlines()
+        if verbose > 0:
+            if six.PY2:
+                assert msg == [
+                    "assert <class 'test_assertrewrite.X'> == 42",
+                    "  -<class 'test_assertrewrite.X'>",
+                    "  +42",
+                ]
+            else:
+                assert msg == [
+                    "assert <class 'test_...e.<locals>.X'> == 42",
+                    "  -<class 'test_assertrewrite.TestAssertionRewrite.test_name.<locals>.X'>",
+                    "  +42",
+                ]
+        else:
+            assert msg == ["assert cls == 42"]
 
-    def test_dont_rewrite_if_hasattr_fails(self):
+    def test_dont_rewrite_if_hasattr_fails(self, request):
         class Y(object):
             """ A class whos getattr fails, but not with `AttributeError` """
 
@@ -173,10 +197,16 @@ class TestAssertionRewrite(object):
         def f():
             assert cls().foo == 2  # noqa
 
-        message = getmsg(f, {"cls": Y})
-        assert "assert 3 == 2" in message
-        assert "+  where 3 = Y.foo" in message
-        assert "+    where Y = cls()" in message
+        # XXX: looks like the "where" should also be there in verbose mode?!
+        message = getmsg(f, {"cls": Y}).splitlines()
+        if request.config.getoption("verbose") > 0:
+            assert message == ["assert 3 == 2", "  -3", "  +2"]
+        else:
+            assert message == [
+                "assert 3 == 2",
+                " +  where 3 = Y.foo",
+                " +    where Y = cls()",
+            ]
 
     def test_assert_already_has_message(self):
         def f():
@@ -552,15 +582,16 @@ class TestAssertionRewrite(object):
 
         getmsg(f, must_pass=True)
 
-    def test_len(self):
+    def test_len(self, request):
         def f():
             values = list(range(10))
             assert len(values) == 11
 
-        assert getmsg(f).startswith(
-            """assert 10 == 11
- +  where 10 = len(["""
-        )
+        msg = getmsg(f)
+        if request.config.getoption("verbose") > 0:
+            assert msg == "assert 10 == 11\n  -10\n  +11"
+        else:
+            assert msg == "assert 10 == 11\n +  where 10 = len([0, 1, 2, 3, 4, 5, ...])"
 
     def test_custom_reprcompare(self, monkeypatch):
         def my_reprcompare(op, left, right):
@@ -608,7 +639,7 @@ class TestAssertionRewrite(object):
 
         assert getmsg(f).startswith("assert '%test' == 'test'")
 
-    def test_custom_repr(self):
+    def test_custom_repr(self, request):
         def f():
             class Foo(object):
                 a = 1
@@ -619,7 +650,11 @@ class TestAssertionRewrite(object):
             f = Foo()
             assert 0 == f.a
 
-        assert r"where 1 = \n{ \n~ \n}.a" in util._format_lines([getmsg(f)])[0]
+        lines = util._format_lines([getmsg(f)])
+        if request.config.getoption("verbose") > 0:
+            assert lines == ["assert 0 == 1\n  -0\n  +1"]
+        else:
+            assert lines == ["assert 0 == 1\n +  where 1 = \\n{ \\n~ \\n}.a"]
 
     def test_custom_repr_non_ascii(self):
         def f():
@@ -796,7 +831,7 @@ def test_rewritten():
         )
         # needs to be a subprocess because pytester explicitly disables this warning
         result = testdir.runpytest_subprocess()
-        result.stdout.fnmatch_lines("*Module already imported*: _pytest")
+        result.stdout.fnmatch_lines(["*Module already imported*: _pytest"])
 
     def test_rewrite_module_imported_from_conftest(self, testdir):
         testdir.makeconftest(
@@ -1123,7 +1158,7 @@ class TestAssertionRewriteHookDetails(object):
         )
         path.join("data.txt").write("Hey")
         result = testdir.runpytest()
-        result.stdout.fnmatch_lines("*1 passed*")
+        result.stdout.fnmatch_lines(["*1 passed*"])
 
 
 def test_issue731(testdir):
@@ -1154,7 +1189,7 @@ class TestIssue925(object):
         """
         )
         result = testdir.runpytest()
-        result.stdout.fnmatch_lines("*E*assert (False == False) == False")
+        result.stdout.fnmatch_lines(["*E*assert (False == False) == False"])
 
     def test_long_case(self, testdir):
         testdir.makepyfile(
@@ -1164,7 +1199,7 @@ class TestIssue925(object):
         """
         )
         result = testdir.runpytest()
-        result.stdout.fnmatch_lines("*E*assert (False == True) == True")
+        result.stdout.fnmatch_lines(["*E*assert (False == True) == True"])
 
     def test_many_brackets(self, testdir):
         testdir.makepyfile(
@@ -1174,7 +1209,7 @@ class TestIssue925(object):
             """
         )
         result = testdir.runpytest()
-        result.stdout.fnmatch_lines("*E*assert True == ((False == True) == True)")
+        result.stdout.fnmatch_lines(["*E*assert True == ((False == True) == True)"])
 
 
 class TestIssue2121:
@@ -1194,7 +1229,33 @@ class TestIssue2121:
             """
         )
         result = testdir.runpytest()
-        result.stdout.fnmatch_lines("*E*assert (1 + 1) == 3")
+        result.stdout.fnmatch_lines(["*E*assert (1 + 1) == 3"])
+
+
+@pytest.mark.skipif(
+    sys.maxsize <= (2 ** 31 - 1), reason="Causes OverflowError on 32bit systems"
+)
+@pytest.mark.parametrize("offset", [-1, +1])
+def test_source_mtime_long_long(testdir, offset):
+    """Support modification dates after 2038 in rewritten files (#4903).
+
+    pytest would crash with:
+
+            fp.write(struct.pack("<ll", mtime, size))
+        E   struct.error: argument out of range
+    """
+    p = testdir.makepyfile(
+        """
+        def test(): pass
+    """
+    )
+    # use unsigned long timestamp which overflows signed long,
+    # which was the cause of the bug
+    # +1 offset also tests masking of 0xFFFFFFFF
+    timestamp = 2 ** 32 + offset
+    os.utime(str(p), (timestamp, timestamp))
+    result = testdir.runpytest()
+    assert result.ret == 0
 
 
 def test_rewrite_infinite_recursion(testdir, pytestconfig, monkeypatch):
@@ -1312,7 +1373,7 @@ class TestEarlyRewriteBailout(object):
         # Setup conditions for py's fspath trying to import pathlib on py34
         # always (previously triggered via xdist only).
         # Ref: https://github.com/pytest-dev/py/pull/207
-        monkeypatch.setattr(sys, "path", [""] + sys.path)
+        monkeypatch.syspath_prepend("")
         monkeypatch.delitem(sys.modules, "pathlib", raising=False)
 
         testdir.makepyfile(
@@ -1333,4 +1394,4 @@ class TestEarlyRewriteBailout(object):
             }
         )
         result = testdir.runpytest()
-        result.stdout.fnmatch_lines("* 1 passed in *")
+        result.stdout.fnmatch_lines(["* 1 passed in *"])
