@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 from __future__ import absolute_import
 from __future__ import division
 from __future__ import print_function
@@ -5,7 +6,7 @@ from __future__ import print_function
 import sys
 import textwrap
 
-import attr
+import importlib_metadata
 
 import _pytest._code
 import pytest
@@ -531,32 +532,26 @@ def test_options_on_small_file_do_not_blow_up(testdir):
 
 
 def test_preparse_ordering_with_setuptools(testdir, monkeypatch):
-    pkg_resources = pytest.importorskip("pkg_resources")
     monkeypatch.delenv("PYTEST_DISABLE_PLUGIN_AUTOLOAD", raising=False)
 
-    def my_iter(group, name=None):
-        assert group == "pytest11"
+    class EntryPoint(object):
+        name = "mytestplugin"
+        group = "pytest11"
 
-        class Dist(object):
-            project_name = "spam"
-            version = "1.0"
+        def load(self):
+            class PseudoPlugin(object):
+                x = 42
 
-            def _get_metadata(self, name):
-                return ["foo.txt,sha256=abc,123"]
+            return PseudoPlugin()
 
-        class EntryPoint(object):
-            name = "mytestplugin"
-            dist = Dist()
+    class Dist(object):
+        files = ()
+        entry_points = (EntryPoint(),)
 
-            def load(self):
-                class PseudoPlugin(object):
-                    x = 42
+    def my_dists():
+        return (Dist,)
 
-                return PseudoPlugin()
-
-        return iter([EntryPoint()])
-
-    monkeypatch.setattr(pkg_resources, "iter_entry_points", my_iter)
+    monkeypatch.setattr(importlib_metadata, "distributions", my_dists)
     testdir.makeconftest(
         """
         pytest_plugins = "mytestplugin",
@@ -569,60 +564,73 @@ def test_preparse_ordering_with_setuptools(testdir, monkeypatch):
 
 
 def test_setuptools_importerror_issue1479(testdir, monkeypatch):
-    pkg_resources = pytest.importorskip("pkg_resources")
     monkeypatch.delenv("PYTEST_DISABLE_PLUGIN_AUTOLOAD", raising=False)
 
-    def my_iter(group, name=None):
-        assert group == "pytest11"
+    class DummyEntryPoint(object):
+        name = "mytestplugin"
+        group = "pytest11"
 
-        class Dist(object):
-            project_name = "spam"
-            version = "1.0"
+        def load(self):
+            raise ImportError("Don't hide me!")
 
-            def _get_metadata(self, name):
-                return ["foo.txt,sha256=abc,123"]
+    class Distribution(object):
+        version = "1.0"
+        files = ("foo.txt",)
+        entry_points = (DummyEntryPoint(),)
 
-        class EntryPoint(object):
-            name = "mytestplugin"
-            dist = Dist()
+    def distributions():
+        return (Distribution(),)
 
-            def load(self):
-                raise ImportError("Don't hide me!")
-
-        return iter([EntryPoint()])
-
-    monkeypatch.setattr(pkg_resources, "iter_entry_points", my_iter)
+    monkeypatch.setattr(importlib_metadata, "distributions", distributions)
     with pytest.raises(ImportError):
         testdir.parseconfig()
 
 
+def test_importlib_metadata_broken_distribution(testdir, monkeypatch):
+    """Integration test for broken distributions with 'files' metadata being None (#5389)"""
+    monkeypatch.delenv("PYTEST_DISABLE_PLUGIN_AUTOLOAD", raising=False)
+
+    class DummyEntryPoint:
+        name = "mytestplugin"
+        group = "pytest11"
+
+        def load(self):
+            return object()
+
+    class Distribution:
+        version = "1.0"
+        files = None
+        entry_points = (DummyEntryPoint(),)
+
+    def distributions():
+        return (Distribution(),)
+
+    monkeypatch.setattr(importlib_metadata, "distributions", distributions)
+    testdir.parseconfig()
+
+
 @pytest.mark.parametrize("block_it", [True, False])
 def test_plugin_preparse_prevents_setuptools_loading(testdir, monkeypatch, block_it):
-    pkg_resources = pytest.importorskip("pkg_resources")
     monkeypatch.delenv("PYTEST_DISABLE_PLUGIN_AUTOLOAD", raising=False)
 
     plugin_module_placeholder = object()
 
-    def my_iter(group, name=None):
-        assert group == "pytest11"
+    class DummyEntryPoint(object):
+        name = "mytestplugin"
+        group = "pytest11"
 
-        class Dist(object):
-            project_name = "spam"
-            version = "1.0"
+        def load(self):
+            return plugin_module_placeholder
 
-            def _get_metadata(self, name):
-                return ["foo.txt,sha256=abc,123"]
+    class Distribution(object):
+        version = "1.0"
+        files = ("foo.txt",)
+        entry_points = (DummyEntryPoint(),)
 
-        class EntryPoint(object):
-            name = "mytestplugin"
-            dist = Dist()
+    def distributions():
+        return (Distribution(),)
 
-            def load(self):
-                return plugin_module_placeholder
-
-        return iter([EntryPoint()])
-
-    monkeypatch.setattr(pkg_resources, "iter_entry_points", my_iter)
+    monkeypatch.setattr(importlib_metadata, "distributions", distributions)
     args = ("-p", "no:mytestplugin") if block_it else ()
     config = testdir.parseconfig(*args)
     config.pluginmanager.import_plugin("mytestplugin")
@@ -639,37 +647,26 @@ def test_plugin_preparse_prevents_setuptools_loading(testdir, monkeypatch, block
     "parse_args,should_load", [(("-p", "mytestplugin"), True), ((), False)]
 )
 def test_disable_plugin_autoload(testdir, monkeypatch, parse_args, should_load):
-    pkg_resources = pytest.importorskip("pkg_resources")
-
-    def my_iter(group, name=None):
-        assert group == "pytest11"
-        assert name == "mytestplugin"
-        return iter([DummyEntryPoint()])
-
-    @attr.s
     class DummyEntryPoint(object):
-        name = "mytestplugin"
+        project_name = name = "mytestplugin"
+        group = "pytest11"
         version = "1.0"
 
-        @property
-        def project_name(self):
-            return self.name
-
         def load(self):
             return sys.modules[self.name]
 
-        @property
-        def dist(self):
-            return self
-
-        def _get_metadata(self, *args):
-            return []
+    class Distribution(object):
+        entry_points = (DummyEntryPoint(),)
+        files = ()
 
     class PseudoPlugin(object):
         x = 42
 
+    def distributions():
+        return (Distribution(),)
+
     monkeypatch.setenv("PYTEST_DISABLE_PLUGIN_AUTOLOAD", "1")
-    monkeypatch.setattr(pkg_resources, "iter_entry_points", my_iter)
+    monkeypatch.setattr(importlib_metadata, "distributions", distributions)
     monkeypatch.setitem(sys.modules, "mytestplugin", PseudoPlugin())
     config = testdir.parseconfig(*parse_args)
     has_loaded = config.pluginmanager.get_plugin("mytestplugin") is not None
@@ -770,7 +767,7 @@ def test_notify_exception(testdir, capfd):
     config = testdir.parseconfig()
     with pytest.raises(ValueError) as excinfo:
         raise ValueError(1)
-    config.notify_exception(excinfo)
+    config.notify_exception(excinfo, config.option)
     out, err = capfd.readouterr()
     assert "ValueError" in err
 
@@ -779,10 +776,17 @@ def test_notify_exception(testdir, capfd):
             return True
 
     config.pluginmanager.register(A())
-    config.notify_exception(excinfo)
+    config.notify_exception(excinfo, config.option)
     out, err = capfd.readouterr()
     assert not err
 
+    config = testdir.parseconfig("-p", "no:terminal")
+    with pytest.raises(ValueError) as excinfo:
+        raise ValueError(1)
+    config.notify_exception(excinfo, config.option)
+    out, err = capfd.readouterr()
+    assert "ValueError" in err
+
 
 def test_load_initial_conftest_last_ordering(testdir, _config_for_test):
     pm = _config_for_test.pluginmanager
@@ -1205,20 +1209,12 @@ def test_config_does_not_load_blocked_plugin_from_args(testdir):
     [
         x
         for x in _pytest.config.default_plugins
-        if x
-        not in [
-            "fixtures",
-            "helpconfig",  # Provides -p.
-            "main",
-            "mark",
-            "python",
-            "runner",
-            "terminal",  # works in OK case (no output), but not with failures.
-        ]
+        if x not in _pytest.config.essential_plugins
     ],
 )
 def test_config_blocked_default_plugins(testdir, plugin):
     if plugin == "debugging":
+        # Fixed in xdist master (after 1.27.0).
         # https://github.com/pytest-dev/pytest-xdist/pull/422
         try:
             import xdist  # noqa: F401
@@ -1229,10 +1225,25 @@ def test_config_blocked_default_plugins(testdir, plugin):
 
     p = testdir.makepyfile("def test(): pass")
     result = testdir.runpytest(str(p), "-pno:%s" % plugin)
+
+    if plugin == "python":
+        assert result.ret == EXIT_USAGEERROR
+        result.stderr.fnmatch_lines(
+            [
+                "ERROR: not found: */test_config_blocked_default_plugins.py",
+                "(no name '*/test_config_blocked_default_plugins.py' in any of [])",
+            ]
+        )
+        return
+
     assert result.ret == EXIT_OK
-    result.stdout.fnmatch_lines(["* 1 passed in *"])
+    if plugin != "terminal":
+        result.stdout.fnmatch_lines(["* 1 passed in *"])
 
     p = testdir.makepyfile("def test(): assert 0")
     result = testdir.runpytest(str(p), "-pno:%s" % plugin)
     assert result.ret == EXIT_TESTSFAILED
-    result.stdout.fnmatch_lines(["* 1 failed in *"])
+    if plugin != "terminal":
+        result.stdout.fnmatch_lines(["* 1 failed in *"])
+    else:
+        assert result.stdout.lines == [""]
