@@ -485,9 +485,27 @@ class TestPython(object):
         tnode = node.find_first_by_tag("testcase")
         tnode.assert_attr(classname="test_xfailure_function", name="test_xfail")
         fnode = tnode.find_first_by_tag("skipped")
-        fnode.assert_attr(message="expected test failure")
+        fnode.assert_attr(type="pytest.xfail", message="42")
         # assert "ValueError" in fnode.toxml()
 
+    def test_xfailure_marker(self, testdir):
+        testdir.makepyfile(
+            """
+            import pytest
+            @pytest.mark.xfail(reason="42")
+            def test_xfail():
+                assert False
+        """
+        )
+        result, dom = runandparse(testdir)
+        assert not result.ret
+        node = dom.find_first_by_tag("testsuite")
+        node.assert_attr(skipped=1, tests=1)
+        tnode = node.find_first_by_tag("testcase")
+        tnode.assert_attr(classname="test_xfailure_marker", name="test_xfail")
+        fnode = tnode.find_first_by_tag("skipped")
+        fnode.assert_attr(type="pytest.xfail", message="42")
+
     def test_xfail_captures_output_once(self, testdir):
         testdir.makepyfile(
             """
@@ -975,6 +993,20 @@ def test_record_property_same_name(testdir):
     pnodes[1].assert_attr(name="foo", value="baz")
 
 
+@pytest.mark.parametrize("fixture_name", ["record_property", "record_xml_attribute"])
+def test_record_fixtures_without_junitxml(testdir, fixture_name):
+    testdir.makepyfile(
+        """
+        def test_record({fixture_name}):
+            {fixture_name}("foo", "bar")
+    """.format(
+            fixture_name=fixture_name
+        )
+    )
+    result = testdir.runpytest()
+    assert result.ret == 0
+
+
 @pytest.mark.filterwarnings("default")
 def test_record_attribute(testdir):
     testdir.makeini(
@@ -1005,8 +1037,9 @@ def test_record_attribute(testdir):
 
 
 @pytest.mark.filterwarnings("default")
-def test_record_attribute_xunit2(testdir):
-    """Ensure record_xml_attribute drops values when outside of legacy family
+@pytest.mark.parametrize("fixture_name", ["record_xml_attribute", "record_property"])
+def test_record_fixtures_xunit2(testdir, fixture_name):
+    """Ensure record_xml_attribute and record_property drop values when outside of legacy family
     """
     testdir.makeini(
         """
@@ -1019,21 +1052,28 @@ def test_record_attribute_xunit2(testdir):
         import pytest
 
         @pytest.fixture
-        def other(record_xml_attribute):
-            record_xml_attribute("bar", 1)
-        def test_record(record_xml_attribute, other):
-            record_xml_attribute("foo", "<1");
-    """
+        def other({fixture_name}):
+            {fixture_name}("bar", 1)
+        def test_record({fixture_name}, other):
+            {fixture_name}("foo", "<1");
+    """.format(
+            fixture_name=fixture_name
+        )
     )
 
     result, dom = runandparse(testdir, "-rw")
-    result.stdout.fnmatch_lines(
-        [
-            "*test_record_attribute_xunit2.py:6:*record_xml_attribute is an experimental feature",
-            "*test_record_attribute_xunit2.py:6:*record_xml_attribute is incompatible with "
-            "junit_family: xunit2 (use: legacy|xunit1)",
-        ]
-    )
+    expected_lines = []
+    if fixture_name == "record_xml_attribute":
+        expected_lines.append(
+            "*test_record_fixtures_xunit2.py:6:*record_xml_attribute is an experimental feature"
+        )
+    expected_lines = [
+        "*test_record_fixtures_xunit2.py:6:*{fixture_name} is incompatible "
+        "with junit_family 'xunit2' (use 'legacy' or 'xunit1')".format(
+            fixture_name=fixture_name
+        )
+    ]
+    result.stdout.fnmatch_lines(expected_lines)
 
 
 def test_random_report_log_xdist(testdir, monkeypatch):
@@ -1203,6 +1243,53 @@ def test_url_property(testdir):
     ), "The URL did not get written to the xml"
 
 
+def test_record_testsuite_property(testdir):
+    testdir.makepyfile(
+        """
+        def test_func1(record_testsuite_property):
+            record_testsuite_property("stats", "all good")
+
+        def test_func2(record_testsuite_property):
+            record_testsuite_property("stats", 10)
+    """
+    )
+    result, dom = runandparse(testdir)
+    assert result.ret == 0
+    node = dom.find_first_by_tag("testsuite")
+    properties_node = node.find_first_by_tag("properties")
+    p1_node = properties_node.find_nth_by_tag("property", 0)
+    p2_node = properties_node.find_nth_by_tag("property", 1)
+    p1_node.assert_attr(name="stats", value="all good")
+    p2_node.assert_attr(name="stats", value="10")
+
+
+def test_record_testsuite_property_junit_disabled(testdir):
+    testdir.makepyfile(
+        """
+        def test_func1(record_testsuite_property):
+            record_testsuite_property("stats", "all good")
+    """
+    )
+    result = testdir.runpytest()
+    assert result.ret == 0
+
+
+@pytest.mark.parametrize("junit", [True, False])
+def test_record_testsuite_property_type_checking(testdir, junit):
+    testdir.makepyfile(
+        """
+        def test_func1(record_testsuite_property):
+            record_testsuite_property(1, 2)
+    """
+    )
+    args = ("--junitxml=tests.xml",) if junit else ()
+    result = testdir.runpytest(*args)
+    assert result.ret == 1
+    result.stdout.fnmatch_lines(
+        ["*TypeError: name parameter needs to be a string, but int given"]
+    )
+
+
 @pytest.mark.parametrize("suite_name", ["my_suite", ""])
 def test_set_suite_name(testdir, suite_name):
     if suite_name:
@@ -1245,3 +1332,30 @@ def test_escaped_skipreason_issue3533(testdir):
     snode = node.find_first_by_tag("skipped")
     assert "1 <> 2" in snode.text
     snode.assert_attr(message="1 <> 2")
+
+
+def test_logging_passing_tests_disabled_does_not_log_test_output(testdir):
+    testdir.makeini(
+        """
+        [pytest]
+        junit_log_passing_tests=False
+        junit_logging=system-out
+    """
+    )
+    testdir.makepyfile(
+        """
+        import pytest
+        import logging
+        import sys
+
+        def test_func():
+            sys.stdout.write('This is stdout')
+            sys.stderr.write('This is stderr')
+            logging.warning('hello')
+    """
+    )
+    result, dom = runandparse(testdir)
+    assert result.ret == 0
+    node = dom.find_first_by_tag("testcase")
+    assert len(node.find_by_tag("system-err")) == 0
+    assert len(node.find_by_tag("system-out")) == 0
