@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 from __future__ import absolute_import
 from __future__ import division
 from __future__ import print_function
@@ -16,7 +17,7 @@ from _pytest.warnings import SHOW_PYTEST_WARNINGS_ARG
 def test_tmpdir_fixture(testdir):
     p = testdir.copy_example("tmpdir/tmpdir_fixture.py")
     results = testdir.runpytest(p)
-    results.stdout.fnmatch_lines("*1 passed*")
+    results.stdout.fnmatch_lines(["*1 passed*"])
 
 
 def test_ensuretemp(recwarn):
@@ -58,8 +59,8 @@ class TestTempdirHandler(object):
         assert tmp2.relto(t.getbasetemp()).startswith("this")
         assert tmp2 != tmp
 
-    @pytest.mark.issue(4425)
     def test_tmppath_relative_basetemp_absolute(self, tmp_path, monkeypatch):
+        """#4425"""
         from _pytest.tmpdir import TempPathFactory
 
         monkeypatch.chdir(tmp_path)
