@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 from __future__ import absolute_import
 from __future__ import division
 from __future__ import print_function
@@ -143,6 +144,29 @@ def test_new_instances(testdir):
     reprec.assertoutcome(passed=2)
 
 
+def test_function_item_obj_is_instance(testdir):
+    """item.obj should be a bound method on unittest.TestCase function items (#5390)."""
+    testdir.makeconftest(
+        """
+        def pytest_runtest_makereport(item, call):
+            if call.when == 'call':
+                class_ = item.parent.obj
+                assert isinstance(item.obj.__self__, class_)
+    """
+    )
+    testdir.makepyfile(
+        """
+        import unittest
+
+        class Test(unittest.TestCase):
+            def test_foo(self):
+                pass
+    """
+    )
+    result = testdir.runpytest_inprocess()
+    result.stdout.fnmatch_lines(["* 1 passed in*"])
+
+
 def test_teardown(testdir):
     testpath = testdir.makepyfile(
         """
@@ -794,7 +818,7 @@ def test_unittest_setup_interaction(testdir, fix_type, stmt):
         )
     )
     result = testdir.runpytest()
-    result.stdout.fnmatch_lines("*3 passed*")
+    result.stdout.fnmatch_lines(["*3 passed*"])
 
 
 def test_non_unittest_no_setupclass_support(testdir):
@@ -930,11 +954,11 @@ def test_class_method_containing_test_issue1558(testdir):
     reprec.assertoutcome(passed=1)
 
 
-@pytest.mark.issue(3498)
 @pytest.mark.parametrize(
     "base", ["six.moves.builtins.object", "unittest.TestCase", "unittest2.TestCase"]
 )
 def test_usefixtures_marker_on_unittest(base, testdir):
+    """#3498"""
     module = base.rsplit(".", 1)[0]
     pytest.importorskip(module)
     testdir.makepyfile(
@@ -1040,4 +1064,4 @@ def test_setup_inheritance_skipping(testdir, test_name, expected_outcome):
     """Issue #4700"""
     testdir.copy_example("unittest/{}".format(test_name))
     result = testdir.runpytest()
-    result.stdout.fnmatch_lines("* {} in *".format(expected_outcome))
+    result.stdout.fnmatch_lines(["* {} in *".format(expected_outcome)])
